@@ -61,10 +61,12 @@ namespace KeePass.App.Configuration
 		DisableKeyChangeDays = 0x8,
 		HidePwQuality = 0x10,
 		DisableUpdateCheck = 0x20,
+		DisableXmlReplace = 0x40,
 
 		HideBuiltInPwGenPrfInEntryDlg = 0x10000,
 		ShowLastAccessTime = 0x20000,
-		HideNewDbInfoDialogs = 0x40000
+		HideNewDbInfoDialogs = 0x40000,
+		HideAutoTypeObfInfo = 0x80000
 	}
 
 	[Flags]
@@ -208,6 +210,14 @@ namespace KeePass.App.Configuration
 			}
 		}
 
+		private bool m_bTreeViewShowLines = false;
+		[DefaultValue(false)]
+		public bool TreeViewShowLines
+		{
+			get { return m_bTreeViewShowLines; }
+			set { m_bTreeViewShowLines = value; }
+		}
+
 		private bool m_bOptScreenReader = false;
 		[DefaultValue(false)]
 		public bool OptimizeForScreenReader
