@@ -71,7 +71,7 @@ namespace KeePass.DataExchange.Formats
 			string strDoc = sr.ReadToEnd();
 			sr.Close();
 
-			XmlDocument doc = new XmlDocument();
+			XmlDocument doc = XmlUtilEx.CreateXmlDocument();
 			doc.LoadXml(strDoc);
 
 			XmlElement xmlRoot = doc.DocumentElement;
