@@ -396,6 +396,8 @@ namespace KeePass.Forms
 				lvg, KPRes.DropToBackOnCopy);
 			m_cdxGuiOptions.CreateItem(Program.Config.MainWindow, "MinimizeAfterClipboardCopy",
 				lvg, KPRes.MinimizeAfterCopy);
+			m_cdxGuiOptions.CreateItem(Program.Config.MainWindow, "MinimizeAfterAutoType",
+				lvg, KPRes.MinimizeAfterAutoType);
 			m_cdxGuiOptions.CreateItem(Program.Config.MainWindow, "MinimizeAfterLocking",
 				lvg, KPRes.MinimizeAfterLocking);
 			m_cdxGuiOptions.CreateItem(Program.Config.MainWindow, "MinimizeAfterOpeningDatabase",
@@ -487,6 +489,8 @@ namespace KeePass.Forms
 				lvg, KPRes.RepeatOnlyWhenHidden);
 			// m_cdxGuiOptions.CreateItem(Program.Config.UI, "UseCustomToolStripRenderer",
 			//	lvg, KPRes.UseCustomToolStripRenderer);
+			m_cdxGuiOptions.CreateItem(Program.Config.UI, "TreeViewShowLines",
+				lvg, KPRes.TreeViewShowLines);
 			m_cdxGuiOptions.CreateItem(Program.Config.UI, "ForceSystemFontUnix",
 				lvg, KPRes.ForceSystemFontUnix);
 
@@ -566,6 +570,8 @@ namespace KeePass.Forms
 				lvg, KPRes.StartMinimizedAndLocked, obNoMin);
 			m_cdxAdvanced.CreateItem(Program.Config.Application.FileClosing, "AutoSave",
 				lvg, KPRes.AutoSaveAtExit);
+			m_cdxAdvanced.CreateItem(Program.Config.Application, "AutoSaveAfterEntryEdit",
+				lvg, KPRes.AutoSaveAfterEntryEdit);
 
 			lvg = new ListViewGroup(KPRes.AfterDatabaseOpen);
 			m_lvAdvanced.Groups.Add(lvg);
