@@ -1,6 +1,6 @@
 /*
   KeePass Password Safe - The Open-Source Password Manager
-  Copyright (C) 2003-2017 Dominik Reichl <dominik.reichl@t-online.de>
+  Copyright (C) 2003-2018 Dominik Reichl <dominik.reichl@t-online.de>
 
   This program is free software; you can redistribute it and/or modify
   it under the terms of the GNU General Public License as published by
@@ -220,6 +220,9 @@ namespace KeePass.Util
 
 					mf.EnsureVisibleEntry(pe.Uuid);
 					mf.UpdateUI(false, null, false, null, false, null, false);
+
+					if(Program.Config.Application.AutoSaveAfterEntryEdit)
+						mf.SaveDatabase(pd, null);
 				}
 				else { Debug.Assert(false); }
 
