@@ -19,11 +19,12 @@
 
 using System;
 using System.Collections.Generic;
-using System.Text;
 using System.Diagnostics;
 using System.IO;
-using System.Xml.Serialization;
+using System.Security.Cryptography;
+using System.Text;
 using System.Threading;
+using System.Xml.Serialization;
 
 using KeePass.Forms;
 using KeePass.Native;
@@ -88,12 +89,16 @@ namespace KeePass.Util
 	public static class IpcUtilEx
 	{
 		internal const string IpcMsgFilePreID = "KeePassIPC-";
-		internal const string IpcMsgFilePostID = "-Msgs.tmp";
+		// internal const string IpcMsgFilePostID = "-Msgs.tmp";
 
 		public const string CmdOpenDatabase = "OpenDatabase";
 		public const string CmdOpenEntryUrl = "OpenEntryUrl";
 		public const string CmdIpcEvent = "IpcEvent";
 
+		private static readonly byte[] IpcOptEnt = new byte[] {
+			0x51, 0xE4, 0xCA, 0x4B, 0xBB, 0x63, 0x57, 0x21
+		};
+
 		/// <summary>
 		/// Event that is raised e.g. when running KeePass with the
 		/// <c>AppDefs.CommandLineOptions.IpcEvent</c> command line parameter.
@@ -108,7 +113,7 @@ namespace KeePass.Util
 			int nId = (int)(MemUtil.BytesToUInt32(CryptoRandom.Instance.GetRandomBytes(
 				4)) & 0x7FFFFFFF);
 
-			if(WriteIpcInfoFile(nId, ipcMsg) == false) return;
+			if(!WriteIpcInfoFile(nId, ipcMsg)) return;
 
 			try
 			{
@@ -157,14 +162,18 @@ namespace KeePass.Util
 
 			try
 			{
-				XmlSerializer xml = new XmlSerializer(typeof(IpcParamEx));
-				FileStream fs = new FileStream(strPath, FileMode.Create, FileAccess.Write,
-					FileShare.None);
+				using(MemoryStream ms = new MemoryStream())
+				{
+					XmlUtilEx.Serialize<IpcParamEx>(ms, ipcMsg);
 
-				try { xml.Serialize(fs, ipcMsg); }
-				catch(Exception) { Debug.Assert(false); }
+					byte[] pb = ms.ToArray();
+					byte[] pbCmp = MemUtil.Compress(pb);
+					byte[] pbEnc = CryptoUtil.ProtectData(pbCmp, IpcOptEnt,
+						DataProtectionScope.CurrentUser);
+
+					File.WriteAllBytes(strPath, pbEnc);
+				}
 
-				fs.Close();
 				return true;
 			}
 			catch(Exception) { Debug.Assert(false); }
@@ -195,16 +204,17 @@ namespace KeePass.Util
 			IpcParamEx ipcParam = null;
 			try
 			{
-				XmlSerializer xml = new XmlSerializer(typeof(IpcParamEx));
-				FileStream fs = new FileStream(strPath, FileMode.Open,
-					FileAccess.Read, FileShare.Read);
+				byte[] pbEnc = File.ReadAllBytes(strPath);
+				byte[] pbCmp = CryptoUtil.UnprotectData(pbEnc, IpcOptEnt,
+					DataProtectionScope.CurrentUser);
+				byte[] pb = MemUtil.Decompress(pbCmp);
 
-				try { ipcParam = (IpcParamEx)xml.Deserialize(fs); }
-				catch(Exception) { Debug.Assert(false); }
-
-				fs.Close();
+				using(MemoryStream ms = new MemoryStream(pb, false))
+				{
+					ipcParam = XmlUtilEx.Deserialize<IpcParamEx>(ms);
+				}
 			}
-			catch(Exception) { }
+			catch(Exception) { Debug.Assert(!File.Exists(strPath)); }
 
 			RemoveIpcInfoFile(nId);
 
@@ -282,7 +292,7 @@ namespace KeePass.Util
 				PwEntry pe = pdb.RootGroup.FindEntry(pwUuid, true);
 				if(pe == null) continue;
 
-				mf.PerformDefaultUrlAction(new PwEntry[]{ pe }, true);
+				mf.PerformDefaultUrlAction(new PwEntry[] { pe }, true);
 				break;
 			}
 		}
