@@ -33,11 +33,13 @@ using System.Windows.Forms;
 using Microsoft.Win32;
 
 using KeePass.App;
+using KeePass.Forms;
 using KeePass.Native;
 using KeePass.Resources;
 using KeePass.Util.Spr;
 
 using KeePassLib;
+using KeePassLib.Delegates;
 using KeePassLib.Serialization;
 using KeePassLib.Utility;
 
@@ -163,14 +165,14 @@ namespace KeePass.Util
 			string strUrl = pe.Strings.ReadSafe(PwDefs.UrlField);
 
 			if(pe.OverrideUrl.Length > 0)
-				WinUtil.OpenUrl(pe.OverrideUrl, pe, true, strUrl);
+				OpenUrl(pe.OverrideUrl, pe, true, strUrl);
 			else
 			{
 				string strOverride = Program.Config.Integration.UrlOverride;
 				if(strOverride.Length > 0)
-					WinUtil.OpenUrl(strOverride, pe, true, strUrl);
+					OpenUrl(strOverride, pe, true, strUrl);
 				else
-					WinUtil.OpenUrl(strUrl, pe, true);
+					OpenUrl(strUrl, pe, true);
 			}
 		}
 
@@ -188,8 +190,21 @@ namespace KeePass.Util
 		public static void OpenUrl(string strUrlToOpen, PwEntry peDataSource,
 			bool bAllowOverride, string strBaseRaw)
 		{
-			// If URL is null, return, do not throw exception.
-			Debug.Assert(strUrlToOpen != null); if(strUrlToOpen == null) return;
+			VoidDelegate f = delegate()
+			{
+				try { OpenUrlPriv(strUrlToOpen, peDataSource, bAllowOverride, strBaseRaw); }
+				catch(Exception) { Debug.Assert(false); }
+			};
+
+			MainForm mf = Program.MainForm;
+			if((mf != null) && mf.InvokeRequired) mf.Invoke(f);
+			else f();
+		}
+
+		private static void OpenUrlPriv(string strUrlToOpen, PwEntry peDataSource,
+			bool bAllowOverride, string strBaseRaw)
+		{
+			if(strUrlToOpen == null) { Debug.Assert(false); return; }
 
 			string strPrevWorkDir = WinUtil.GetWorkingDirectory();
 			string strThisExe = WinUtil.GetExecutable();
@@ -197,41 +212,10 @@ namespace KeePass.Util
 			string strExeDir = UrlUtil.GetFileDirectory(strThisExe, false, true);
 			WinUtil.SetWorkingDirectory(strExeDir);
 
-			string strUrlFlt = strUrlToOpen;
-			strUrlFlt = strUrlFlt.TrimStart(new char[]{ ' ', '\t', '\r', '\n' });
-
-			PwDatabase pwDatabase = null;
-			try
-			{
-				pwDatabase = Program.MainForm.DocumentManager.SafeFindContainerOf(
-					peDataSource);
-			}
-			catch(Exception) { Debug.Assert(false); }
-
-			bool bEncCmd = WinUtil.IsCommandLineUrl(strUrlFlt);
-
-			SprContext ctx = new SprContext(peDataSource, pwDatabase,
-				SprCompileFlags.All, false, bEncCmd);
-			ctx.Base = strBaseRaw;
-			ctx.BaseIsEncoded = false;
-
-			string strUrl = SprEngine.Compile(strUrlFlt, ctx);
-
-			string strOvr = Program.Config.Integration.UrlSchemeOverrides.GetOverrideForUrl(
-				strUrl);
-			if(!bAllowOverride) strOvr = null;
-			if(strOvr != null)
-			{
-				bool bEncCmdOvr = WinUtil.IsCommandLineUrl(strOvr);
-
-				SprContext ctxOvr = new SprContext(peDataSource, pwDatabase,
-					SprCompileFlags.All, false, bEncCmdOvr);
-				ctxOvr.Base = strUrl;
-				ctxOvr.BaseIsEncoded = bEncCmd;
-
-				strUrl = SprEngine.Compile(strOvr, ctxOvr);
-			}
+			string strUrl = CompileUrl(strUrlToOpen, peDataSource, bAllowOverride,
+				strBaseRaw);
 
+			Process p = null;
 			if(WinUtil.IsCommandLineUrl(strUrl))
 			{
 				string strApp, strArgs;
@@ -240,10 +224,9 @@ namespace KeePass.Util
 
 				try
 				{
-					if((strArgs != null) && (strArgs.Length > 0))
-						Process.Start(strApp, strArgs);
-					else
-						Process.Start(strApp);
+					if(!string.IsNullOrEmpty(strArgs))
+						p = Process.Start(strApp, strArgs);
+					else p = Process.Start(strApp);
 				}
 				catch(Win32Exception)
 				{
@@ -261,18 +244,59 @@ namespace KeePass.Util
 			}
 			else // Standard URL
 			{
-				try { Process.Start(strUrl); }
+				try { p = Process.Start(strUrl); }
 				catch(Exception exUrl)
 				{
 					MessageService.ShowWarning(strUrl, exUrl);
 				}
 			}
 
+			try { if(p != null) p.Dispose(); }
+			catch(Exception) { Debug.Assert(false); }
+
 			// Restore previous working directory
 			WinUtil.SetWorkingDirectory(strPrevWorkDir);
 
 			// SprEngine.Compile might have modified the database
-			Program.MainForm.UpdateUI(false, null, false, null, false, null, false);
+			MainForm mf = Program.MainForm;
+			if(mf != null) mf.UpdateUI(false, null, false, null, false, null, false);
+		}
+
+		internal static string CompileUrl(string strUrlToOpen, PwEntry pe,
+			bool bAllowOverride, string strBaseRaw)
+		{
+			MainForm mf = Program.MainForm;
+			PwDatabase pd = null;
+			try { if(mf != null) pd = mf.DocumentManager.SafeFindContainerOf(pe); }
+			catch(Exception) { Debug.Assert(false); }
+
+			string strUrlFlt = strUrlToOpen;
+			strUrlFlt = strUrlFlt.TrimStart(new char[] { ' ', '\t', '\r', '\n' });
+
+			bool bEncCmd = WinUtil.IsCommandLineUrl(strUrlFlt);
+
+			SprContext ctx = new SprContext(pe, pd, SprCompileFlags.All, false, bEncCmd);
+			ctx.Base = strBaseRaw;
+			ctx.BaseIsEncoded = false;
+
+			string strUrl = SprEngine.Compile(strUrlFlt, ctx);
+
+			string strOvr = Program.Config.Integration.UrlSchemeOverrides.GetOverrideForUrl(
+				strUrl);
+			if(!bAllowOverride) strOvr = null;
+			if(strOvr != null)
+			{
+				bool bEncCmdOvr = WinUtil.IsCommandLineUrl(strOvr);
+
+				SprContext ctxOvr = new SprContext(pe, pd, SprCompileFlags.All,
+					false, bEncCmdOvr);
+				ctxOvr.Base = strUrl;
+				ctxOvr.BaseIsEncoded = bEncCmd;
+
+				strUrl = SprEngine.Compile(strOvr, ctxOvr);
+			}
+
+			return strUrl;
 		}
 
 		public static void OpenUrlWithApp(string strUrlToOpen, PwEntry peDataSource,
@@ -307,26 +331,28 @@ namespace KeePass.Util
 
 				psi.UseShellExecute = false;
 
-				Process.Start(psi);
+				Process p = Process.Start(psi);
+				if(p != null) p.Dispose();
 			}
-			catch(Exception exCmd)
+			catch(Exception ex)
 			{
 				string strInf = KPRes.FileOrUrl + ": " + strApp;
 				if((strArgs != null) && (strArgs.Length > 0))
 					strInf += MessageService.NewParagraph +
 						KPRes.Arguments + ": " + strArgs;
 
-				MessageService.ShowWarning(strInf, exCmd);
+				MessageService.ShowWarning(strInf, ex);
 			}
 		}
 
 		public static void Restart()
 		{
-			try { Process.Start(WinUtil.GetExecutable()); }
-			catch(Exception exRestart)
+			try
 			{
-				MessageService.ShowWarning(exRestart);
+				Process p = Process.Start(WinUtil.GetExecutable());
+				if(p != null) p.Dispose();
 			}
+			catch(Exception ex) { MessageService.ShowWarning(ex); }
 		}
 
 		public static string GetExecutable()
@@ -349,34 +375,35 @@ namespace KeePass.Util
 		/// Shorten a path.
 		/// </summary>
 		/// <param name="strPath">Path to make shorter.</param>
-		/// <param name="nMaxChars">Maximum number of characters in the returned string.</param>
+		/// <param name="cchMax">Maximum number of characters in the returned string.</param>
 		/// <returns>Shortened path.</returns>
-		public static string CompactPath(string strPath, int nMaxChars)
+		public static string CompactPath(string strPath, int cchMax)
 		{
 			Debug.Assert(strPath != null);
 			if(strPath == null) throw new ArgumentNullException("strPath");
-			Debug.Assert(nMaxChars >= 0);
-			if(nMaxChars < 0) throw new ArgumentOutOfRangeException("nMaxChars");
+			Debug.Assert(cchMax >= 0);
+			if(cchMax < 0) throw new ArgumentOutOfRangeException("cchMax");
 
-			if(nMaxChars == 0) return string.Empty;
-			if(strPath.Length <= nMaxChars) return strPath;
+			if(strPath.Length <= cchMax) return strPath;
+			if(cchMax == 0) return string.Empty;
 
 			try
 			{
-				StringBuilder sb = new StringBuilder(strPath.Length * 2 + 4);
+				if(!NativeLib.IsUnix())
+				{
+					StringBuilder sb = new StringBuilder(strPath.Length + 2);
 
-				if(NativeMethods.PathCompactPathEx(sb, strPath, (uint)nMaxChars, 0) == false)
-					return StrUtil.CompactString3Dots(strPath, nMaxChars);
-
-				Debug.Assert(sb.Length <= nMaxChars);
-				if((sb.Length <= nMaxChars) && (sb.Length != 0))
-					return sb.ToString();
-				else
-					return StrUtil.CompactString3Dots(strPath, nMaxChars);
+					if(NativeMethods.PathCompactPathEx(sb, strPath, (uint)cchMax + 1, 0))
+					{
+						if((sb.Length <= cchMax) && (sb.Length != 0))
+							return sb.ToString();
+						else { Debug.Assert(false); }
+					}
+				}
 			}
 			catch(Exception) { Debug.Assert(false); }
 
-			return StrUtil.CompactString3Dots(strPath, nMaxChars);
+			return StrUtil.CompactString3Dots(strPath, cchMax);
 		}
 
 		public static bool FlushStorageBuffers(char chDriveLetter, bool bOnlyIfRemovable)
@@ -550,7 +577,8 @@ namespace KeePass.Util
 				// Elevate on Windows Vista and higher
 				if(WinUtil.IsAtLeastWindowsVista) psi.Verb = "runas";
 
-				Process.Start(psi);
+				Process p = Process.Start(psi);
+				if(p != null) p.Dispose();
 			}
 			catch(Exception ex)
 			{
